hkitty_palette: A Hello kitty palette generator

View source: R/colors.R

hkitty_paletteR Documentation

A Hello kitty palette generator

Description

These are a handful of color palettes from Wes Anderson movies.

Usage

hkitty_palette(name, n, type = c("discrete", "continuous"))

Arguments

name

Name of desired palette. Choices are: hellokitty1, hellokitty2

n

Number of colors desired. If omitted, uses all colors.

type

Either "continuous" or "discrete". Use continuous if you want to automatically interpolate between colors. @importFrom graphics rgb rect par image text

Value

A vector of colors.

Examples

hkitty_palette("hellokitty1")
hkitty_palette("hellokitty2")
hkitty_palette("hellokitty1", 3)

# If you need more colors than normally found in a palette, you
# can use a continuous palette to interpolate between existing
# colors
pal <- hkitty_palette(name = "hellokitty2", n = 21, type = "continuous")

hellokitty documentation built on June 17, 2026, 5:06 p.m.