| hkitty_palette | R Documentation |
These are a handful of color palettes from Wes Anderson movies.
hkitty_palette(name, n, type = c("discrete", "continuous"))
name |
Name of desired palette. Choices are:
|
n |
Number of colors desired. If omitted, uses all colors. |
type |
Either "continuous" or "discrete". Use continuous if you want to automatically interpolate between colors. @importFrom graphics rgb rect par image text |
A vector of colors.
hkitty_palette("hellokitty1")
hkitty_palette("hellokitty2")
hkitty_palette("hellokitty1", 3)
# If you need more colors than normally found in a palette, you
# can use a continuous palette to interpolate between existing
# colors
pal <- hkitty_palette(name = "hellokitty2", n = 21, type = "continuous")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.